﻿Param($clustername);

# For non-terminating errors force execution to stop and throw an exception
$ErrorActionPreference = "Stop";

$ErrorCode_Success = 0;
$ErrorCode_Failed = 1;

Write-Output "Waiting for Cluster...";

$i = 0
$bGetHostAddresses = $False;
while(!$bGetHostAddresses -and ($i -le 100))
{
    try
    {
        Write-Output "Waiting for DNS...";
        $bGetHostAddresses = $([System.Net.Dns]::GetHostAddresses($clusterName));
    }
    catch
    {
       Write-Output "Caught an exception:";
       Write-Output "    Exception Type: $($_.Exception.GetType().FullName)";
       Write-Output "    Exception Message: $($_.Exception.Message)";
       Write-Output "    Exception HResult: $($_.Exception.HResult)";
       [System.Threading.Thread]::Sleep(20000);
    }    
    $i++
}

$i = 0
$bGetCluster = $False;
while(!$bGetCluster -and ($i -le 100))
{
    try
    {
        Write-Output "Waiting for Get-Cluster...";
        $bGetCluster = $(Get-Cluster -Name $clusterName)
    }
    catch
    {
       Write-Output "Caught an exception:";
       Write-Output "    Exception Type: $($_.Exception.GetType().FullName)";
       Write-Output "    Exception Message: $($_.Exception.Message)";
       Write-Output "    Exception HResult: $($_.Exception.HResult)";
       [System.Threading.Thread]::Sleep(5000);
    }    
    $i++
}

if ($bGetCluster)
{
    Write-Output "Cluster is up"
}
else
{
    Write-Output "Cluster is not up. Check the DNS server"
    Exit $ErrorCode_Failed;
}

try
{
    Write-Output "=============================";
    Write-Output "Adding second node to cluster";
    Write-Output "=============================";

    # Get cluster using its name 
    $cluster = Get-Cluster -Name $clustername -ErrorAction Ignore;
    if (!$cluster)
    { 
        Write-Output "Failed to get cluster using cluster name $clustername";
        Exit $ErrorCode_Failed;
    }
    
    $found = $false;  
    $nodes = Get-ClusterNode -Cluster $cluster;
    foreach ($node in $nodes) {
        if ($node.Name -eq $env:COMPUTERNAME) {
            $found = $true;
            break;
        }
    }

    if ($found -eq $false) {
        # Adding second node to cluster
        Add-ClusterNode -Cluster $cluster -Name $env:COMPUTERNAME;
    }

    Exit $ErrorCode_Success;
}
catch
{
   Write-Output "Caught an exception:";
   Write-Output "    Exception Type: $($_.Exception.GetType().FullName)";
   Write-Output "    Exception Message: $($_.Exception.Message)";
   Write-Output "    Exception HResult: $($_.Exception.HResult)";   

   Exit $($_.Exception.HResult);
}


