﻿$ErrorActionPreference = "stop";

$ErrorCode_Success = 0;
$ErrorCode_Failed = 1;

Function Get-Subnet {
    Param(
        [Net.IPAddress]$IPAddress,
        [int]          $PrefixLength)

    try 
    {
        $AddressBytes = $IPAddress.GetAddressBytes();

        $NumberOfBytesToZero = $AddressBytes.Length - [int][System.Math]::Floor($PrefixLength / 8);
        $Remainder = $PrefixLength % 8;


        for($Index = 0; $Index -lt ($NumberOfBytesToZero - 1); $Index++) 
        {
            $AddressBytes[$AddressBytes.Length-1-$Index] = 0;
        }

        if( $Remainder -eq 0 ) 
        {
            $AddressBytes[$AddressBytes.Length - $NumberOfBytesToZero] = 0;
        }
        else 
        {
            $BitsToMove = 8 - $Remainder;
            $Mask = (255 -shr $BitsToMove) -shl $BitsToMove;
            $AddressBytes[$AddressBytes.Length - $NumberOfBytesToZero] = $AddressBytes[$AddressBytes.Length - $NumberOfBytesToZero] -band $Mask;
        }

        $SubnetIP = new-object System.Net.IPAddress(,$AddressBytes);
        $SubnetIPWithPrefixString = "{0}/{1}" -f $SubnetIP, $PrefixLength;

        Return $SubnetIPWithPrefixString;
    }
    catch 
    {
        Write-Output "Caught an exception:";
        Write-Output "    Exception Type: $($_.Exception.GetType().FullName)";
        Write-Output "    Exception Message: $($_.Exception.Message)";
        Write-Output "    Exception HResult: $($_.Exception.HResult)";
        Exit $($_.Exception.HResult);
    } 
}
