﻿. .\Get-Subnet.ps1;

$ErrorActionPreference = "stop";

$ErrorCode_Success = 0;
$ErrorCode_Failed = 1;

#
# Process Adapters on the machine
$Adapters = get-netadapter;
foreach ($Adapter in $Adapters) {

    $NewAdapterName = "";

    Write-Output "Processing Adapter: $($Adapter.Name) with ifindex: $($Adapter.ifindex)";     

    #
    # For the disconnected adapter, name it to BackEnd
    if ($Adapter.Status -eq "Disconnected") 
    {
       Write-Output "    Adapter is disconnected. Naming it to 'BackEnd'"; 
       rename-netadapter -Name $Adapter.name -NewName "BackEnd";
       continue;
    }

    #
    # Ignore other adapters
    if ($Adapter.Status -ne "Up")
    {
       Write-Output "    Adapter Status is not UP... Ignoring Adapter"; 
       continue;
    }

    #
    # Getting the NetProfile.Name 
    Write-Output "    Getting NetProfile.Name from NetIPConfiguration";     
    $NetIPConfig = Get-NetIPConfiguration | where {$_.InterfaceIndex -eq $Adapter.ifindex};
    $NetProfileName = $NetIPConfig.NetProfile.Name;

    Write-Output "    Getting IPv4 Address";
    $ip = get-netIPAddress | where {$_.InterfaceIndex -eq $Adapter.ifindex -and  $_.addressfamily -eq 2};
    if (!$ip)
    {
        Write-Output "    No IPv4 Address on the Adapter proceeding with with IPv6";
        $ip = get-netIPAddress | where {$_.InterfaceIndex -eq $Adapter.ifindex -and  $_.addressfamily -eq 23};
        if (!$ip)
        {
            Write-Output "Failed to get IP Address for adapter $($Adapter.Name) with ifindex: $($Adapter.ifindex)";
            Exit $ErrorCode_Failed;        
        }
    }        

    Write-Output "    Calculate SubNet IP for IP Address $($ip[0].IPAddress) and PrefixLength $($ip[0].PrefixLength)";
    $SubNetIP = Get-Subnet -IPAddress $ip[0].IPAddress -PrefixLength $ip[0].PrefixLength;
    if ($SubNetIP -eq "")
    {
        Write-Output "Failed to calculate SubNet IP for IP Address $($ip[0].IPAddress) and PrefixLength $($ip[0].PrefixLength)";
        Exit $ErrorCode_Failed; 
    }

    $SubNetIP = $SubNetIP -replace '/','_';
    Write-Output "    New name will be based on: $SubNetIP";

    # Remove invalid characters
    $NewAdapterName = $NewAdapterName -replace ':','';


    #
    # If the other nic already has this name increment the postfix
    $PostFix = 1;
    if ($NetProfleName -eq "")
    {
        $AdapterName = $SubNetIP;
    }
    else
    {
        $AdapterName =  $NetProfileName + "_" + $SubNetIP;
    }
    
    $TmpAdapters = get-netadapter; 
    foreach ($TmpAdapter in $TmpAdapters)
    {
        if (($TmpAdapter.Name -eq $AdapterName) -and ($TmpAdapter.ifIndex -ne $Adapter.ifIndex)) 
        {
            $AdapterName = $AdapterName + "_" + [String]$PostFix;
            $PostFix++;
            break;
        }
    }
   
    #
    # Now rename the NIC
    try 
    {
        Write-Output "    Renaming adapter from '$($Adapter.name)' to '$AdapterName'";
        rename-netAdapter -Name $Adapter.name -NewName $AdapterName;       
    }
    catch 
    {
        Write-Output "Caught an exception:";
        Write-Output "    Exception Type: $($_.Exception.GetType().FullName)";
        Write-Output "    Exception Message: $($_.Exception.Message)";
        Write-Output "    Exception HResult: $($_.Exception.HResult)";
    }   
}

Exit $ErrorCode_Success;